package forester

  1. Overview
  2. Docs

Module Sem.DocSource

Sourceval peek_title : doc -> string option
Sourceval title_as_string : doc -> string option

Best-effort rendering of a doc title as a string, to use in text-only contexts.

Returns None when the document does not have a title. Returns Some s otherwise, where s is a rendering of the title. Elements that could not be rendered are dropped. Consequently, when the title could not be rendered at all, s is the empty string.

Sourceval sort : doc list -> doc list